<?php

class BP_Group_Invite_Email {
	public $id;
	public $recipient_email;
	public $group_id;
	public $sender_id;
	
	/**
	 * __construct()
	 *
	 * The constructor will either create a new empty object if no ID is set, or fill the object
	 * with a row from the table, or the passed parameters, if an ID is provided.
	 */
	public function __construct( $id = null, $params = false ) {
		global $wpdb, $bp;
		
		if ( $id && ctype_digit( $id ) ) {
			$this->id = $id;
			if( $params ) {
				$this->populate_passed($params);
			} else {
				$this->populate( $this->id );
			}
		}
	}
	
	/**
	 * populate()
	 *
	 * This method will populate the object with a row from the database, based on the
	 * ID passed to the constructor.
	 */
	private function populate() {
		global $wpdb, $bp, $creds;
		
		if ( $row = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM {$bp->group_invite_email->table_name} WHERE id = %d", $this->id ) ) ) {
			foreach( $this as $field => $value ) {
				$this->$field = $row->$field;
			}
		}
	}
	
	/**
	 * populate_passed()
	 *
	 * This method will populate the object with the passed parameters, 
	 * saving a call to the database
	 */
	private function populate_passed($params) {
		
		foreach( $this as $key => $value ) {
			if( isset( $params[$key] ) )
				$this->$key = $params[$key];	
		}
	}
	
	/**
	 * save()
	 *
	 * This method will save an object to the database. It will dynamically switch between
	 * INSERT and UPDATE depending on whether or not the object already exists in the database.
	 */
	public function save() {
		global $wpdb, $bp;
		
		
		do_action( 'bp_group_invite_email_data_before_save', $this );

		$result = $wpdb->query( $wpdb->prepare( 
			"INSERT INTO {$bp->group_invite_email->table_name} ( 
				recipient_email,
				group_id, 
				sender_id
			) VALUES ( 
				%s, %d, %d
			)", 
				$this->recipient_email,
				$this->group_id,
				$this->sender_id
			) );

		if ( !$result )
			return false;
		
		if ( !$this->id ) {
			$this->id = $wpdb->insert_id;
		}	
		
		do_action( 'bp_group_invite_email_data_after_save', $this ); 
		
		return $result;
	}

	/**
	 * delete()
	 *
	 * This method will delete the corresponding row for an object from the database.
	 */	
	public function delete() {
		global $wpdb, $bp;
		
		return $wpdb->query( $wpdb->prepare( "DELETE FROM {$bp->group_invite_email->table_name} WHERE id = %d LIMIT 1", $this->id ) );
	}
	
	/**
	 * send_email()
	 *
	 * This method sends a explanation email to the user
	 */
	 public function send_email() {
		global $bp;

		do_action('bp_group_invite_email_send_email');

		$website_name = get_blog_option( 1, 'blogname' );
		$sender_name = bp_core_get_user_displayname($this->sender_id);
		$sender_profile_link = bp_core_get_userlink($this->sender_id,false,true);
		$group_name = $bp->groups->current_group->name;
		$sign_up = bp_get_signup_page(false);

		$to = $this->recipient_email;
		$subject = '[' . $website_name . '] ' . sprintf( __( 'You have been invited to %s', 'bp-group-documents' ), $group_name );

		$message = sprintf( __(
'You have been invited to the group: %s on the website: %s.

You have been invited by: %s.

Please visit the registration page: %s to sign up and confirm.

To see %s\'s profile: %s

------------------------
', 'bp-group-invite-email'),$group_name, $website_name, $sender_name, $sign_up, $sender_name, $sender_profile_link );

		$message = apply_filters('bp_group_invite_email_message',$message);

		wp_mail( $to, $subject, $message );
	 }


	/* Static Functions */

	public static function delete_by_email_group($email, $group_id) {
		global $wpdb, $bp;
		
		return $wpdb->query( $wpdb->prepare( "DELETE FROM {$bp->group_invite_email->table_name} WHERE group_id = %d AND recipient_email = '%s' LIMIT 1", $group_id, $email ) );

	}

	/**
	 * user_has_invite()
	 *
	 * checks for a row in the database with the user's email
	 * if one is found, it returns the matching group,
	 * otherwise, returns false
	 */
	 public function user_has_invites($email){
		global $bp, $wpdb;

		$result = $wpdb->get_col( $wpdb->prepare("SELECT group_id FROM {$bp->group_invite_email->table_name} WHERE recipient_email LIKE %s",$email));

		if( count($result) ) {
			return $result;
		}
		return false;
	 }


}
